==> haskell-tagstream-conduit-0.5.5.3-236-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagstream-conduit
version: 0.5.5.3
id: tagstream-conduit-0.5.5.3-KoBliKtuJpXF5XM5II2AWY
key: tagstream-conduit-0.5.5.3-KoBliKtuJpXF5XM5II2AWY
license: BSD-3-Clause
maintainer: yi.codeplayer@gmail.com
author: yihuang
homepage: http://github.com/yihuang/tagstream-conduit
synopsis: streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.
category: Web, Conduit
abi: 705abca4ba2683b61fc2fb02b7cb738f
exposed: True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils
import-dirs: /usr/lib/ghc-8.6.3/site-local/tagstream-conduit-0.5.5.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/tagstream-conduit-0.5.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/tagstream-conduit-0.5.5.3
hs-libraries: HStagstream-conduit-0.5.5.3-KoBliKtuJpXF5XM5II2AWY
depends:
    attoparsec-0.13.2.2-Jk4D4QRG8ZrHQCpZMillSF base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    conduit-1.3.1-1ncJAGOGfjaJsj5t5Gnhwi
    conduit-extra-1.3.0-IzWwWcOYLQ57jxjedr8PfJ
    data-default-0.7.1.1-5KnoR2THpEuGUXIWRdYUvc
    resourcet-1.2.2-5i3IrLQ8cCMFRKp3qE5jS8 text-1.2.3.1
    transformers-0.5.5.0 xml-conduit-1.8.0.1-AO1YiNbZEMJ73kiuXLn1mk
haddock-interfaces: /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock
haddock-html: /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagstream-conduit-0.5.5.3-239-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagstream-conduit
version: 0.5.5.3
id: tagstream-conduit-0.5.5.3-9NssxQYiZk33i4Oz6rI1eJ
key: tagstream-conduit-0.5.5.3-9NssxQYiZk33i4Oz6rI1eJ
license: BSD-3-Clause
maintainer: yi.codeplayer@gmail.com
author: yihuang
homepage: http://github.com/yihuang/tagstream-conduit
synopsis: streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.
category: Web, Conduit
abi: 7c81bca387bf99400ca645376671f7d1
exposed: True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils
import-dirs: /usr/lib/ghc-8.6.3/site-local/tagstream-conduit-0.5.5.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/tagstream-conduit-0.5.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/tagstream-conduit-0.5.5.3
hs-libraries: HStagstream-conduit-0.5.5.3-9NssxQYiZk33i4Oz6rI1eJ
depends:
    attoparsec-0.13.2.2-5xLw3754VYU1jRp4MrlfX3 base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    conduit-1.3.1-JmMdk65SNka3dWWZlerpD5
    conduit-extra-1.3.1-GJzJEYE5Jcu9j08rqwCOyH
    data-default-0.7.1.1-5KnoR2THpEuGUXIWRdYUvc
    resourcet-1.2.2-Lrcu6EHQLGUJY1Qaiy4SUl text-1.2.3.1
    transformers-0.5.5.0 xml-conduit-1.8.0.1-FYr1XwZ6GZT1p40K7HYm4S
haddock-interfaces: /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock
haddock-html: /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
